@@ -1,21 +1,5 @@
-/*
- * Copyright 2003-2021 The Music Player Daemon Project
- * http://www.musicpd.org
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- */
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The Music Player Daemon Project
 
 #include "MpcdecDecoderPlugin.hxx"
 #include "../DecoderAPI.hxx"
@@ -52,7 +36,8 @@ mpc_read_cb(mpc_reader *reader, void *ptr, mpc_int32_t size)
 	auto *data =
 		(struct mpc_decoder_data *)reader->data;
 
-	return decoder_read(data->client, data->is, ptr, size);
+	return decoder_read(data->client, data->is,
+			    {reinterpret_cast<std::byte *>(ptr), static_cast<std::size_t>(size)});
 }
 
 static mpc_bool_t
@@ -241,9 +226,9 @@ mpcdec_decode(DecoderClient &client, InputStream &is)
 		long bit_rate = unsigned(frame.bits) * audio_format.sample_rate
 			/ (1000 * frame.samples);
 
-		cmd = client.SubmitData(is,
-					chunk, ret * sizeof(chunk[0]),
-					bit_rate);
+		cmd = client.SubmitAudio(is,
+					 std::span{chunk, ret},
+					 bit_rate);
 	} while (cmd != DecoderCommand::STOP);
 }
 
