@@ -1,21 +1,5 @@
-/*
- * Copyright 2003-2021 The Music Player Daemon Project
- * http://www.musicpd.org
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
- */
+// SPDX-License-Identifier: GPL-2.0-or-later
+// Copyright The Music Player Daemon Project
 
 #include "PlaylistSong.hxx"
 #include "SongLoader.hxx"
@@ -24,6 +8,7 @@
 #include "fs/Traits.hxx"
 #include "song/DetachedSong.hxx"
 #include "util/UriExtract.hxx"
+#include "util/UriUtil.hxx"
 
 #include <algorithm>
 #include <string>
@@ -40,6 +25,7 @@ merge_song_metadata(DetachedSong &add, const DetachedSong &base) noexcept
 	}
 
 	add.SetLastModified(base.GetLastModified());
+	add.SetAdded(base.GetAdded());
 
 	if (add.GetStartTime().IsZero()) {
 		add.SetStartTime(base.GetStartTime());
@@ -47,6 +33,9 @@ merge_song_metadata(DetachedSong &add, const DetachedSong &base) noexcept
 	if (add.GetEndTime().IsZero()) {
 		add.SetEndTime(base.GetEndTime());
 	}
+
+	if (!add.GetAudioFormat().IsDefined())
+		add.SetAudioFormat(base.GetAudioFormat());
 }
 
 static bool
@@ -92,9 +81,15 @@ playlist_check_translate_song(DetachedSong &song, std::string_view base_uri,
 	}
 #endif
 
-	if (base_uri.data() != nullptr && !uri_has_scheme(uri) &&
-	    !PathTraitsUTF8::IsAbsolute(uri))
+	if (base_uri.data() != nullptr &&
+	    !PathTraitsUTF8::IsAbsoluteOrHasScheme(uri)) {
 		song.SetURI(PathTraitsUTF8::Build(base_uri, uri));
+		uri = song.GetURI();
+	}
+
+	/* Remove dot segments */
+	std::string new_uri = uri_squash_dot_segments(uri);
+	song.SetURI(std::move(new_uri));
 
 	return playlist_check_load_song(song, loader);
 }
